# Generated by roxygen2: do not edit by hand

export(date_breaks_gg)
export(date_breaks_n)
export(esp_navy)
export(esp_pal)
export(getBLSFiles)
export(getDallasTrimPCE)
export(getFRED)
export(getNIPAFiles)
export(getPCEInflation)
export(getUnrateFRED)
export(logLinearProjection)
export(scale_color_esp)
export(scale_colour_esp)
export(scale_fill_esp)
export(theme_esp)
importFrom(dplyr,arrange)
importFrom(dplyr,as_tibble)
importFrom(dplyr,case_when)
importFrom(dplyr,coalesce)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,inner_join)
importFrom(dplyr,lag)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,pull)
importFrom(dplyr,select)
importFrom(dplyr,summarize)
importFrom(dplyr,transmute)
importFrom(dplyr,ungroup)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(grid,unit)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(httr,status_code)
importFrom(httr,user_agent)
importFrom(magrittr,"%>%")
importFrom(purrr,compact)
importFrom(purrr,pmap)
importFrom(purrr,reduce)
importFrom(readr,cols)
importFrom(readr,read_csv)
importFrom(readr,read_tsv)
importFrom(rlang,.data)
importFrom(stats,lm)
importFrom(stats,predict)
importFrom(utils,data)
importFrom(utils,globalVariables)
importFrom(utils,head)
