#' @importFrom utils globalVariables
utils::globalVariables(c(
  "series_id", "value", "TableId", "SeriesCode", "Value", "TotalGDP",
  "SeriesLabel", "PCEweight", "DataValue_P1", "WDataValue_P1",
  "LineNo", "Period", "TableIdList", "TableId:LineNo", "%SeriesCode",
  "..date", "..value", ".data", ".date", ".row_id"
))
