% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme_esp.R
\name{esp_theme}
\alias{esp_theme}
\alias{theme_esp}
\alias{scale_color_esp}
\alias{scale_fill_esp}
\alias{scale_colour_esp}
\title{ESP Theme and Color Scales}
\usage{
theme_esp(base_family = "Public Sans")

scale_color_esp(...)

scale_fill_esp(...)

scale_colour_esp(...)
}
\arguments{
\item{base_family}{Base font family for the theme. Defaults to "Public Sans".}

\item{...}{Passed to the underlying ggplot2 scale functions.}
}
\value{
A ggplot2 theme or scale object.
}
\description{
Custom theme and color palette for Economic Security Project graphics.
}
