% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getUnrateFRED.R
\name{getUnrateFRED}
\alias{getUnrateFRED}
\title{Get Full Unemployment Rate from FRED}
\usage{
getUnrateFRED()
}
\value{
A tibble with columns:
\item{date}{Observation date}
\item{unemploy_level}{Civilian unemployment level (in thousands)}
\item{lf_level}{Civilian labor force level (in thousands)}
\item{full_unrate}{Unemployment rate (decimal)}
}
\description{
Downloads the civilian unemployment level and labor force level from
FRED, and calculates the unemployment rate as
\eqn{\text{unemploy\_level} / \text{lf\_level}}.
}
\examples{
\dontrun{
  getUnrateFRED()
}
}
